@@ -44,6 +44,19 @@ has screenCfg => sub {
     }
 };
 
+# if no user is assigned, all access checks are positive, this allows to explore the
+# modules full capabilities during startup
+has 'user'=> sub ($self) {
+    my $mockUser = bless {}, 'MockUser';
+    unless (defined &MockUser::may) {
+        *MockUser::may = sub ($mockSelf, $right) {
+            # $self->log->debug("MockUser::may($right) -> true");
+            return 1;
+        };
+    }
+    return $mockUser;
+};
+
 =head2 screenOpts
 
 Returns a hash of options for the screen Options
@@ -131,6 +144,10 @@ sub massageConfig {
             $popup->massageConfig($cfg);
         }
     }
+    if (ref $self->user eq 'MockUser') {
+        # $self->log->debug("massageConfig is done. undefining user");
+        $self->user(undef);
+    }
     return;
 }
 
